..
      Copyright 2020 Mirantis Inc.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Amphorav2
=========

This is extension of the reference driver for Octavia. It adopts taskflow
jobboard feature and saves task states into the persistence backend, this
allows to continue task execution if controller work was interrupted.

Default provider name: **amphorav2**

The driver package: https://pypi.org/project/octavia/

The driver source: https://opendev.org/openstack/octavia/

The documentation: https://docs.openstack.org/octavia/latest/

Where to report issues with the driver: https://storyboard.openstack.org/#!/project/openstack/octavia
